package docar.storage.volume;

import java.io.File;
import java.io.IOException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * <pre>
 * 문서 유형 파일 필터.
 * (MS-Office, HTML, Text, XML, PDF 형식만 허용)
 * </pre>
 * 
 * @author "Sunny Kwak"
 *
 */
public class DocumentFilter implements Filter {

	final Logger logger = LoggerFactory.getLogger(DocumentFilter.class);
	private static final String[] EXTENSIONS = { "doc", "docx", "xls", "xlsx",
			"ppt", "pptx", "htm", "html", "txt", "xml", "pdf" };

	@Override
	public boolean allowed(File file) {
		boolean allowed = false;
		if (file.isDirectory()) {
			allowed = true;
		} else {
			String fileName = file.getName();
			String fileExtension = fileName.substring(
					fileName.lastIndexOf(".") + 1).toLowerCase();

			for (String extension : EXTENSIONS) {
				if (fileExtension.equals(extension)) {
					allowed = true;
					break;
				}
			}
		}

		if (logger.isDebugEnabled()) {
			try {
				logger.debug("{} is {}", file.getCanonicalPath(),
						allowed ? "allowed" : "not allowed");
			} catch (IOException ignored) {
				// do nothing
			}
		}

		return allowed;
	}

}
